@@ -11,6 +11,8 @@ describe 'mistral::db::sync' do
         :path        => '/usr/bin',
         :user        => 'mistral',
         :refreshonly => 'true',
+        :try_sleep   => 5,
+        :tries       => 10,
         :logoutput   => 'on_failure'
       )
 
