@@ -64,6 +64,9 @@ describe 'mistral' do
       is_expected.to contain_mistral_config('keystone_authtoken/admin_password').with(
        :value => 'foo'
       )
+      is_expected.to contain_mistral_config('DEFAULT/os_actions_endpoint_type').with(
+        :value => '<SERVICE DEFAULT>'
+      )
     end
 
   end
@@ -103,6 +106,16 @@ describe 'mistral' do
     end
   end
 
+  describe 'with rabbit transport url configured' do
+    let :params do
+      req_params.merge({'default_transport_url' => 'rabbit://user:pass@host:1234/virt' })
+    end
+
+    it 'should contain transport_url' do
+      is_expected.to contain_mistral_config('DEFAULT/transport_url').with(:value => 'rabbit://user:pass@host:1234/virt')
+    end
+  end
+
   describe 'with rabbitmq heartbeats' do
     let :params do
       req_params.merge({'rabbit_heartbeat_timeout_threshold' => '60', 'rabbit_heartbeat_rate' => '10'})
@@ -211,4 +224,14 @@ describe 'mistral' do
     end
   end
 
+  describe 'with os_actions_keystone_endpoint overriden' do
+    let :params do
+      req_params.merge({
+        :os_actions_endpoint_type => 'internal',
+      })
+    end
+
+    it { is_expected.to contain_mistral_config('DEFAULT/os_actions_endpoint_type').with_value('internal') }
+  end
+
 end
